--
-- Definition of a dual port ROM for KCPSM2 or KCPSM3 program defined by control.psm
-- and assmbled using KCPSM2 or KCPSM3 assembler.
--
-- Standard IEEE libraries
--
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;
--
-- The Unisim Library is used to define Xilinx primitives. It is also used during
-- simulation. The source can be viewed at %XILINX%\vhdl\src\unisims\unisim_VCOMP.vhd
--  
library unisim;
use unisim.vcomponents.all;
--
--
entity control is
    Port (      address : in std_logic_vector(9 downto 0);
            instruction : out std_logic_vector(17 downto 0);
             proc_reset : out std_logic;
                    clk : in std_logic);
    end control;
--
architecture low_level_definition of control is
--
-- Declare signals internal to this module
--
signal jaddr     : std_logic_vector(10 downto 0);
signal jparity   : std_logic_vector(0 downto 0);
signal jdata     : std_logic_vector(7 downto 0);
signal doa       : std_logic_vector(7 downto 0);
signal dopa      : std_logic_vector(0 downto 0);
signal tdo1      : std_logic;
signal tdo2      : std_logic;
signal update    : std_logic;
signal shift     : std_logic;
signal reset     : std_logic;
signal tdi       : std_logic;
signal sel1      : std_logic;
signal drck1     : std_logic;
signal drck1_buf : std_logic;
signal sel2      : std_logic;
signal drck2     : std_logic;
signal capture   : std_logic;
signal tap5      : std_logic;
signal tap11     : std_logic;
signal tap17     : std_logic;
--
-- Attributes to define ROM contents during implementation synthesis. 
-- The information is repeated in the generic map for functional simulation
--
attribute INIT_00 : string; 
attribute INIT_01 : string; 
attribute INIT_02 : string; 
attribute INIT_03 : string; 
attribute INIT_04 : string; 
attribute INIT_05 : string; 
attribute INIT_06 : string; 
attribute INIT_07 : string; 
attribute INIT_08 : string; 
attribute INIT_09 : string; 
attribute INIT_0A : string; 
attribute INIT_0B : string; 
attribute INIT_0C : string; 
attribute INIT_0D : string; 
attribute INIT_0E : string; 
attribute INIT_0F : string; 
attribute INIT_10 : string; 
attribute INIT_11 : string; 
attribute INIT_12 : string; 
attribute INIT_13 : string; 
attribute INIT_14 : string; 
attribute INIT_15 : string; 
attribute INIT_16 : string; 
attribute INIT_17 : string; 
attribute INIT_18 : string; 
attribute INIT_19 : string; 
attribute INIT_1A : string; 
attribute INIT_1B : string; 
attribute INIT_1C : string; 
attribute INIT_1D : string; 
attribute INIT_1E : string; 
attribute INIT_1F : string; 
attribute INIT_20 : string; 
attribute INIT_21 : string; 
attribute INIT_22 : string; 
attribute INIT_23 : string; 
attribute INIT_24 : string; 
attribute INIT_25 : string; 
attribute INIT_26 : string; 
attribute INIT_27 : string; 
attribute INIT_28 : string; 
attribute INIT_29 : string; 
attribute INIT_2A : string; 
attribute INIT_2B : string; 
attribute INIT_2C : string; 
attribute INIT_2D : string; 
attribute INIT_2E : string; 
attribute INIT_2F : string; 
attribute INIT_30 : string; 
attribute INIT_31 : string; 
attribute INIT_32 : string; 
attribute INIT_33 : string; 
attribute INIT_34 : string; 
attribute INIT_35 : string; 
attribute INIT_36 : string; 
attribute INIT_37 : string; 
attribute INIT_38 : string; 
attribute INIT_39 : string; 
attribute INIT_3A : string; 
attribute INIT_3B : string; 
attribute INIT_3C : string; 
attribute INIT_3D : string; 
attribute INIT_3E : string; 
attribute INIT_3F : string; 
attribute INITP_00 : string;
attribute INITP_01 : string;
attribute INITP_02 : string;
attribute INITP_03 : string;
attribute INITP_04 : string;
attribute INITP_05 : string;
attribute INITP_06 : string;
attribute INITP_07 : string;
--
-- Attributes to define ROM contents during implementation synthesis.
--
attribute INIT_00 of ram_1024_x_18 : label is  "034D5C110146021F40050039500C4031500340480033021F026F022801AD0143";
attribute INIT_01 of ram_1024_x_18 : label is  "4015003950624033503F4032500C4031501340480033021F0278401303454003";
attribute INIT_02 of ram_1024_x_18 : label is  "403650C3403550D440345081403350664032500C4031502040480033021F0293";
attribute INIT_03 of ram_1024_x_18 : label is  "0333A00001B801B801B80F3F021FA000021401B80F3E021F021F4022003950CC";
attribute INIT_04 of ram_1024_x_18 : label is  "70500506038F021F01EE60000386021F4042850150484507F350018205000161";
attribute INIT_05 of ram_1024_x_18 : label is  "402003455460501061070112021F01EE6007039C021F404FC5015055450101EE";
attribute INIT_06 of ram_1024_x_18 : label is  "1050021F016113500161134004000500016103F0402002C9016103CC4013034D";
attribute INIT_07 of ram_1024_x_18 : label is  "02C9546E449854752407A500840101EE1030018202220222022201EE104001EE";
attribute INIT_08 of ram_1024_x_18 : label is  "8E01F3E01340140058860219150058860219036401618E01F3E0030F0E084003";
attribute INIT_09 of ram_1024_x_18 : label is  "0219037101B88F301F40037404005CC2449054C2450001618E01F3E013500161";
attribute INIT_0A of ram_1024_x_18 : label is  "021FF5E08E01F4E01530018214300182549A4408840101618E01F3E01300589A";
attribute INIT_0B of ram_1024_x_18 : label is  "034554C1540054C1551074E0CE0175E0012C020B021F01EE104001EE1050039C";
attribute INIT_0C of ram_1024_x_18 : label is  "01820371031F021F402002C90161130058C302190371031F021F4003034D4003";
attribute INIT_0D of ram_1024_x_18 : label is  "8E01F4E01530018214300182036401618E01F3E003AA0E08402002C901EE1030";
attribute INIT_0E of ram_1024_x_18 : label is  "022204080371037401EE10308E01F3E00182037E01EE104001EE10508E01F5E0";
attribute INIT_0F of ram_1024_x_18 : label is  "039C021FF5E08E01F4E0153001821430018254EFC40101EE10308E01F3E00182";
attribute INIT_10 of ram_1024_x_18 : label is  "40030345551054005510551074E0CE0175E0012C020C021F01EE104001EE1050";
attribute INIT_11 of ram_1024_x_18 : label is  "E0185D202101F13011000000023869066805670466036502640163004003034D";
attribute INIT_12 of ram_1024_x_18 : label is  "7450010000000508A000551BC201030804080508060807080808090E0008010E";
attribute INIT_13 of ram_1024_x_18 : label is  "552FC20185015531C301040E00080108060EE140E0025D372601F64016000308";
attribute INIT_14 of ram_1024_x_18 : label is  "C00800015D4AE200C101019A01BD0201C0080000A000C0080001A000E1FFE0FF";
attribute INIT_15 of ram_1024_x_18 : label is  "2001A0014002A00022015556C101B200015D019A01B602015551C101019A0138";
attribute INIT_16 of ram_1024_x_18 : label is  "556DC101019A0148C0080000A0005562C20101754167016A5966030C0208A000";
attribute INIT_17 of ram_1024_x_18 : label is  "C101019A0143C00800015578C101019A0108C0080000A000019A019AC0080001";
attribute INIT_18 of ram_1024_x_18 : label is  "0108C0080001558AC101019A0104C0080000A0005583C20101870208A000557E";
attribute INIT_19 of ram_1024_x_18 : label is  "019A0128A000559BC001000BA0005596C101019A013F0308015D5590C101019A";
attribute INIT_1A of ram_1024_x_18 : label is  "C40101A80414A00055A9C30101A30314A00055A4C201019E0219A000559FC101";
attribute INIT_1B of ram_1024_x_18 : label is  "81010130A000CF0441B851BC20024000A0004F0141B255B620044000A00055AE";
attribute INIT_1C of ram_1024_x_18 : label is  "7010A000C0F6B80080C6A000A0DFBC00407BB8004061A000803AC1015DBFC00A";
attribute INIT_1D of ram_1024_x_18 : label is  "000E000E1100A0009200B80001CB7010810102069200020602061200B80001CB";
attribute INIT_1E of ram_1024_x_18 : label is  "1F2001DDA000803A800759ECC00AA000110001E9A00F1010120001E9000E000E";
attribute INIT_1F of ram_1024_x_18 : label is  "03061300B80002081030A00001EE107001EE108001EE1090A00001B81F1001B8";
attribute INIT_20 of ram_1024_x_18 : label is  "B80080075E12C011B800C0E9B80080B9A000D030B80002081020030603060306";
attribute INIT_21 of ram_1024_x_18 : label is  "0F0DA00001FB1200021413000214A00001C510F001B801B2A000800AA000C0F6";
attribute INIT_22 of ram_1024_x_18 : label is  "01B80F6301B80F6901B80F50021F021FA00001B80F2DA00001B80F20A00001B8";
attribute INIT_23 of ram_1024_x_18 : label is  "0F5301B80F44022201B80F6501B80F7A01B80F6101B80F6C01B80F4201B80F6F";
attribute INIT_24 of ram_1024_x_18 : label is  "01B80F6D01B80F6F01B80F43022201B80F3201B80F3301B80F3401B80F3201B8";
attribute INIT_25 of ram_1024_x_18 : label is  "0F7201B80F6F01B80F7401B80F6101B80F6301B80F6901B80F6E01B80F7501B8";
attribute INIT_26 of ram_1024_x_18 : label is  "021FA000021F021F01B80F3001B80F3001B80F2E01B80F3101B80F76022201B8";
attribute INIT_27 of ram_1024_x_18 : label is  "021F0307022501B80F3102D0021F021FA000021F0307022501B80F3102D0021F";
attribute INIT_28 of ram_1024_x_18 : label is  "022202DE02220328022501B80F33021F0356022202DE02220331022501B80F32";
attribute INIT_29 of ram_1024_x_18 : label is  "02220331022501B80F32021F0307022501B80F3102D0021F021FA000021F0356";
attribute INIT_2A of ram_1024_x_18 : label is  "0F34021F0356022202E5022202F20222033A022501B80F33021F0356022202E5";
attribute INIT_2B of ram_1024_x_18 : label is  "031F0222033A022501B80F35021F0356022202E5022202F202220331022501B8";
attribute INIT_2C of ram_1024_x_18 : label is  "A000021F01B80F4B01B80F4F021FA000021F031F02220331022501B80F36021F";
attribute INIT_2D of ram_1024_x_18 : label is  "01B80F52A000021F01B80F7001B80F6C01B80F6501B80F48022501B80F48021F";
attribute INIT_2E of ram_1024_x_18 : label is  "0F7901B80F7201B80F6F01B80F6D01B80F6501B80F4DA00001B80F4D01B80F4F";
attribute INIT_2F of ram_1024_x_18 : label is  "01B80F6801B80F6301B80F7401B80F6101B80F7201B80F6301B80F53A00001B8";
attribute INIT_30 of ram_1024_x_18 : label is  "0F6501B80F7401B80F7301B80F6101B80F4DA00001B80F6401B80F6101B80F70";
attribute INIT_31 of ram_1024_x_18 : label is  "0F42A00001B80F7401B80F6501B80F7301B80F6501B80F52022201B80F7201B8";
attribute INIT_32 of ram_1024_x_18 : label is  "01B80F7001B80F6901B80F6B01B80F53A00001B80F6501B80F7401B80F7901B8";
attribute INIT_33 of ram_1024_x_18 : label is  "01B80F6901B80F7201B80F57A00001B80F6401B80F6101B80F6501B80F52A000";
attribute INIT_34 of ram_1024_x_18 : label is  "0F6101B80F46A00001B801B80F7301B80F6101B80F50A00001B80F6501B80F74";
attribute INIT_35 of ram_1024_x_18 : label is  "0F6E01B80F6101B801B80F6D01B80F6F01B80F43A00001B80F6C01B80F6901B8";
attribute INIT_36 of ram_1024_x_18 : label is  "01B80F7301B80F6501B80F7201B801B80F6401B80F61021FA00001B80F6401B8";
attribute INIT_37 of ram_1024_x_18 : label is  "0F45021FA00001B80F6101B80F7401B80F6101B80F64021FA00001B80F3D01B8";
attribute INIT_38 of ram_1024_x_18 : label is  "0F73437101B80F6501B80F6401B80F6F01B80F63437101B80F5301B80F2F01B8";
attribute INIT_39 of ram_1024_x_18 : label is  "01B80F5201B80F43437101B80F6C01B80F6101B80F6901B80F7201B80F6501B8";
attribute INIT_3A of ram_1024_x_18 : label is  "0000000000000000000000000000000000000000000000000000000043710F43";
attribute INIT_3B of ram_1024_x_18 : label is  "0000000000000000000000000000000000000000000000000000000000000000";
attribute INIT_3C of ram_1024_x_18 : label is  "0000000000000000000000000000000000000000000000000000000000000000";
attribute INIT_3D of ram_1024_x_18 : label is  "0000000000000000000000000000000000000000000000000000000000000000";
attribute INIT_3E of ram_1024_x_18 : label is  "0000000000000000000000000000000000000000000000000000000000000000";
attribute INIT_3F of ram_1024_x_18 : label is  "43FE800100000000000000000000000000000000000000000000000000000000";
attribute INITP_00 of ram_1024_x_18 : label is "F7573FF33CC0CFCFFD3F3F770FCFDDB32FCEF3FF7777777FFDDDDFFFFFFDDFFF";
attribute INITP_01 of ram_1024_x_18 : label is "F98CF71BCFC6FCC6633F60FCFFFCFFFFF744CF33E633D763FD33776360F3FD83";
attribute INITP_02 of ram_1024_x_18 : label is "723722F8DC8B7FE24274F0DC8D708A20D76A834000B6AAAA3400000FFDD133CC";
attribute INITP_03 of ram_1024_x_18 : label is "8B2CCCB33976303AA26C668B2662665D4AF48F4B72DCB72DCB4B72F723722DCB";
attribute INITP_04 of ram_1024_x_18 : label is "FF3FBFCFEFCCCCCF33333333CCCF333333CCCCCCCCCFB2CB2CCECF999D998B2A";
attribute INITP_05 of ram_1024_x_18 : label is "CCCCCCCB333332CCCBCCCCF3BCCEFFF3FFCFFFFF3FFFFCFFFF3FCFEFFFF3FFFC";
attribute INITP_06 of ram_1024_x_18 : label is "3B3333B3CCCF33B333CCCB3332F332CCCCCB3332CCCCB3332CCCCCF333332CCC";
attribute INITP_07 of ram_1024_x_18 : label is "F0000000000000000000000000000000000000000000000CCCF333333CCCCF33";
--
begin
--
  --Instantiate the Xilinx primitive for a block RAM
  ram_1024_x_18: RAMB16_S9_S18
  --synthesis translate_off
  --INIT values repeated to define contents for functional simulation
  generic map (INIT_00 => X"034D5C110146021F40050039500C4031500340480033021F026F022801AD0143",
               INIT_01 => X"4015003950624033503F4032500C4031501340480033021F0278401303454003",
               INIT_02 => X"403650C3403550D440345081403350664032500C4031502040480033021F0293",
               INIT_03 => X"0333A00001B801B801B80F3F021FA000021401B80F3E021F021F4022003950CC",
               INIT_04 => X"70500506038F021F01EE60000386021F4042850150484507F350018205000161",
               INIT_05 => X"402003455460501061070112021F01EE6007039C021F404FC5015055450101EE",
               INIT_06 => X"1050021F016113500161134004000500016103F0402002C9016103CC4013034D",
               INIT_07 => X"02C9546E449854752407A500840101EE1030018202220222022201EE104001EE",
               INIT_08 => X"8E01F3E01340140058860219150058860219036401618E01F3E0030F0E084003",
               INIT_09 => X"0219037101B88F301F40037404005CC2449054C2450001618E01F3E013500161",
               INIT_0A => X"021FF5E08E01F4E01530018214300182549A4408840101618E01F3E01300589A",
               INIT_0B => X"034554C1540054C1551074E0CE0175E0012C020B021F01EE104001EE1050039C",
               INIT_0C => X"01820371031F021F402002C90161130058C302190371031F021F4003034D4003",
               INIT_0D => X"8E01F4E01530018214300182036401618E01F3E003AA0E08402002C901EE1030",
               INIT_0E => X"022204080371037401EE10308E01F3E00182037E01EE104001EE10508E01F5E0",
               INIT_0F => X"039C021FF5E08E01F4E0153001821430018254EFC40101EE10308E01F3E00182",
               INIT_10 => X"40030345551054005510551074E0CE0175E0012C020C021F01EE104001EE1050",
               INIT_11 => X"E0185D202101F13011000000023869066805670466036502640163004003034D",
               INIT_12 => X"7450010000000508A000551BC201030804080508060807080808090E0008010E",
               INIT_13 => X"552FC20185015531C301040E00080108060EE140E0025D372601F64016000308",
               INIT_14 => X"C00800015D4AE200C101019A01BD0201C0080000A000C0080001A000E1FFE0FF",
               INIT_15 => X"2001A0014002A00022015556C101B200015D019A01B602015551C101019A0138",
               INIT_16 => X"556DC101019A0148C0080000A0005562C20101754167016A5966030C0208A000",
               INIT_17 => X"C101019A0143C00800015578C101019A0108C0080000A000019A019AC0080001",
               INIT_18 => X"0108C0080001558AC101019A0104C0080000A0005583C20101870208A000557E",
               INIT_19 => X"019A0128A000559BC001000BA0005596C101019A013F0308015D5590C101019A",
               INIT_1A => X"C40101A80414A00055A9C30101A30314A00055A4C201019E0219A000559FC101",
               INIT_1B => X"81010130A000CF0441B851BC20024000A0004F0141B255B620044000A00055AE",
               INIT_1C => X"7010A000C0F6B80080C6A000A0DFBC00407BB8004061A000803AC1015DBFC00A",
               INIT_1D => X"000E000E1100A0009200B80001CB7010810102069200020602061200B80001CB",
               INIT_1E => X"1F2001DDA000803A800759ECC00AA000110001E9A00F1010120001E9000E000E",
               INIT_1F => X"03061300B80002081030A00001EE107001EE108001EE1090A00001B81F1001B8",
               INIT_20 => X"B80080075E12C011B800C0E9B80080B9A000D030B80002081020030603060306",
               INIT_21 => X"0F0DA00001FB1200021413000214A00001C510F001B801B2A000800AA000C0F6",
               INIT_22 => X"01B80F6301B80F6901B80F50021F021FA00001B80F2DA00001B80F20A00001B8",
               INIT_23 => X"0F5301B80F44022201B80F6501B80F7A01B80F6101B80F6C01B80F4201B80F6F",
               INIT_24 => X"01B80F6D01B80F6F01B80F43022201B80F3201B80F3301B80F3401B80F3201B8",
               INIT_25 => X"0F7201B80F6F01B80F7401B80F6101B80F6301B80F6901B80F6E01B80F7501B8",
               INIT_26 => X"021FA000021F021F01B80F3001B80F3001B80F2E01B80F3101B80F76022201B8",
               INIT_27 => X"021F0307022501B80F3102D0021F021FA000021F0307022501B80F3102D0021F",
               INIT_28 => X"022202DE02220328022501B80F33021F0356022202DE02220331022501B80F32",
               INIT_29 => X"02220331022501B80F32021F0307022501B80F3102D0021F021FA000021F0356",
               INIT_2A => X"0F34021F0356022202E5022202F20222033A022501B80F33021F0356022202E5",
               INIT_2B => X"031F0222033A022501B80F35021F0356022202E5022202F202220331022501B8",
               INIT_2C => X"A000021F01B80F4B01B80F4F021FA000021F031F02220331022501B80F36021F",
               INIT_2D => X"01B80F52A000021F01B80F7001B80F6C01B80F6501B80F48022501B80F48021F",
               INIT_2E => X"0F7901B80F7201B80F6F01B80F6D01B80F6501B80F4DA00001B80F4D01B80F4F",
               INIT_2F => X"01B80F6801B80F6301B80F7401B80F6101B80F7201B80F6301B80F53A00001B8",
               INIT_30 => X"0F6501B80F7401B80F7301B80F6101B80F4DA00001B80F6401B80F6101B80F70",
               INIT_31 => X"0F42A00001B80F7401B80F6501B80F7301B80F6501B80F52022201B80F7201B8",
               INIT_32 => X"01B80F7001B80F6901B80F6B01B80F53A00001B80F6501B80F7401B80F7901B8",
               INIT_33 => X"01B80F6901B80F7201B80F57A00001B80F6401B80F6101B80F6501B80F52A000",
               INIT_34 => X"0F6101B80F46A00001B801B80F7301B80F6101B80F50A00001B80F6501B80F74",
               INIT_35 => X"0F6E01B80F6101B801B80F6D01B80F6F01B80F43A00001B80F6C01B80F6901B8",
               INIT_36 => X"01B80F7301B80F6501B80F7201B801B80F6401B80F61021FA00001B80F6401B8",
               INIT_37 => X"0F45021FA00001B80F6101B80F7401B80F6101B80F64021FA00001B80F3D01B8",
               INIT_38 => X"0F73437101B80F6501B80F6401B80F6F01B80F63437101B80F5301B80F2F01B8",
               INIT_39 => X"01B80F5201B80F43437101B80F6C01B80F6101B80F6901B80F7201B80F6501B8",
               INIT_3A => X"0000000000000000000000000000000000000000000000000000000043710F43",
               INIT_3B => X"0000000000000000000000000000000000000000000000000000000000000000",
               INIT_3C => X"0000000000000000000000000000000000000000000000000000000000000000",
               INIT_3D => X"0000000000000000000000000000000000000000000000000000000000000000",
               INIT_3E => X"0000000000000000000000000000000000000000000000000000000000000000",
               INIT_3F => X"43FE800100000000000000000000000000000000000000000000000000000000",    
               INITP_00 => X"F7573FF33CC0CFCFFD3F3F770FCFDDB32FCEF3FF7777777FFDDDDFFFFFFDDFFF",
               INITP_01 => X"F98CF71BCFC6FCC6633F60FCFFFCFFFFF744CF33E633D763FD33776360F3FD83",
               INITP_02 => X"723722F8DC8B7FE24274F0DC8D708A20D76A834000B6AAAA3400000FFDD133CC",
               INITP_03 => X"8B2CCCB33976303AA26C668B2662665D4AF48F4B72DCB72DCB4B72F723722DCB",
               INITP_04 => X"FF3FBFCFEFCCCCCF33333333CCCF333333CCCCCCCCCFB2CB2CCECF999D998B2A",
               INITP_05 => X"CCCCCCCB333332CCCBCCCCF3BCCEFFF3FFCFFFFF3FFFFCFFFF3FCFEFFFF3FFFC",
               INITP_06 => X"3B3333B3CCCF33B333CCCB3332F332CCCCCB3332CCCCB3332CCCCCF333332CCC",
               INITP_07 => X"F0000000000000000000000000000000000000000000000CCCF333333CCCCF33")
  --synthesis translate_on
  port map(    DIB => "0000000000000000",
              DIPB => "00",
               ENB => '1',
               WEB => '0',
              SSRB => '0',
              CLKB => clk,
             ADDRB => address,
               DOB => instruction(15 downto 0),
              DOPB => instruction(17 downto 16),
               DIA => jdata,
              DIPA => jparity,
               ENA => sel1,
               WEA => '1',
              SSRA => '0',
              CLKA => update,
              ADDRA=> jaddr,
               DOA => doa(7 downto 0),
              DOPA => dopa); 
  v2_bscan: BSCAN_VIRTEX2 
  port map(   TDO1 => tdo1,
         TDO2 => tdo2,
            UPDATE => update,
             SHIFT => shift,
             RESET => reset,
               TDI => tdi,
              SEL1 => sel1,
             DRCK1 => drck1,
              SEL2 => sel2,
             DRCK2 => drck2,
      CAPTURE => capture);
  --buffer signal used as a clock
  upload_clock: BUFG
  port map( I => drck1,
            O => drck1_buf);
  -- Assign the reset to be active whenever the uploading subsystem is active
  proc_reset <= sel1;
  srlC1: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => tdi,
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jaddr(10),
            Q15 => jaddr(8));
  flop1: FD
  port map ( D => jaddr(10),
             Q => jaddr(9),
             C => drck1_buf);
  srlC2: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => jaddr(8),
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jaddr(7),
            Q15 => tap5);
  flop2: FD
  port map ( D => jaddr(7),
             Q => jaddr(6),
             C => drck1_buf);
  srlC3: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => tap5,
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jaddr(5),
            Q15 => jaddr(3));
  flop3: FD
  port map ( D => jaddr(5),
             Q => jaddr(4),
             C => drck1_buf);
  srlC4: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => jaddr(3),
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jaddr(2),
            Q15 => tap11);
  flop4: FD
  port map ( D => jaddr(2),
             Q => jaddr(1),
             C => drck1_buf);
  srlC5: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => tap11,
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jaddr(0),
            Q15 => jdata(7));
  flop5: FD
  port map ( D => jaddr(0),
             Q => jparity(0),
             C => drck1_buf);
  srlC6: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => jdata(7),
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jdata(6),
            Q15 => tap17);
  flop6: FD
  port map ( D => jdata(6),
             Q => jdata(5),
             C => drck1_buf);
  srlC7: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => tap17,
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jdata(4),
            Q15 => jdata(2));
  flop7: FD
  port map ( D => jdata(4),
             Q => jdata(3),
             C => drck1_buf);
  srlC8: SRLC16E
  --synthesis translate_off
  generic map (INIT => X"0000")
  --synthesis translate_on
  port map(   D => jdata(2),
             CE => '1',
            CLK => drck1_buf,
             A0 => '1',
             A1 => '0',
             A2 => '1',
             A3 => '1',
              Q => jdata(1),
            Q15 => tdo1);
  flop8: FD
  port map ( D => jdata(1),
             Q => jdata(0),
             C => drck1_buf);
end low_level_definition;
--
------------------------------------------------------------------------------------
--
-- END OF FILE control.vhd
--
------------------------------------------------------------------------------------
